<?php # $Id: serendipity_lang_pt.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation (c) by Agner Olson <agner@agner.net>
# with an initial work of Ranulfo Netto <rcnetto@yahoo.com>
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'ISO-8859-1');
@define('SQL_CHARSET', 'latin1');
@define('DATE_LOCALES', 'pt_BR.ISO-8859-1, pt_BR.ISO8859-1, pt_BR, portuguese brazilian, pt');
@define('DATE_FORMAT_ENTRY', '%A, %e de %B de %Y');
@define('WYSIWYG_LANG', 'pt_pt');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', 'Painel de Administrao do Serendipity');
@define('HAVE_TO_BE_LOGGED_ON', 'Voc deve entrar no sistema para ver esta pgina');
@define('WRONG_USERNAME_OR_PASSWORD', 'Voc deve ter fornecido nome de usurio ou senha invlidos');
@define('APPEARANCE', 'Aparncia');
@define('MANAGE_STYLES', 'Gerenciar estilos');
@define('CONFIGURE_PLUGINS', 'Configurar Plugins');
@define('CONFIGURATION', 'Configurao');
@define('BACK_TO_BLOG', 'De volta ao Weblog');
@define('LOGIN', 'Login');
@define('LOGOUT', 'Logout');
@define('LOGGEDOUT', 'Logged out.');
@define('CREATE', 'Criar');
@define('SAVE', 'Salvar');
@define('NAME', 'Nome');
@define('CREATE_NEW_CAT', 'Criar nova categoria');
@define('I_WANT_THUMB', 'Quero usar miniaturas em meu artigo.');
@define('I_WANT_BIG_IMAGE', 'Quero usar a maior imagem em meu artigo.');
@define('I_WANT_NO_LINK', ' Quero exibi-la como imagem');
@define('I_WANT_IT_TO_LINK', 'Quero exibi-la como um link para esta URL:');
@define('BACK', 'Volta');
@define('FORWARD', 'Encaminha');
@define('ANONYMOUS', 'Annimo');
@define('NEW_TRACKBACK_TO', 'Novo trackback feito para');
@define('NEW_COMMENT_TO', 'Novo comentrio enviado para');
@define('RECENT', 'Recente...');
@define('OLDER', 'Antigos...');
@define('DONE', 'Pronto');
@define('WELCOME_BACK', 'Bem-vindo de volta,');
@define('TITLE', 'Ttulo');
@define('DESCRIPTION', 'Descrio');
@define('PLACEMENT', 'Localizao');
@define('DELETE', 'Excluir');
@define('SAVE', 'Salvar');
@define('UP', 'Acima');
@define('DOWN', 'Abaixo');
@define('ENTRIES', 'Artigos:');
@define('NEW_ENTRY', 'Novo artigo');
@define('EDIT_ENTRIES', 'Editar artigos');
@define('CATEGORIES', 'Categorias');
@define('WARNING_THIS_BLAHBLAH', "ATENO:\\nIsso pode levar muito tempo se existirem muitas imagens sem miniaturas.");
@define('CREATE_THUMBS', 'Reconstruir Miniaturas');
@define('MANAGE_IMAGES', 'Gerenciar imagens');
@define('NAME', 'Nome');
@define('EMAIL', 'E-mail');
@define('HOMEPAGE', 'Pgina pessoal');
@define('COMMENT', 'Comentrio');
@define('REMEMBER_INFO', 'Relembrar Informaes? ');
@define('SUBMIT_COMMENT', 'Enviar Comentrio');
@define('NO_ENTRIES_TO_PRINT', 'Nenhum artigo para imprimir');
@define('COMMENTS', 'Comentrios');
@define('ADD_COMMENT', 'Adicionar Comentrios');
@define('NO_COMMENTS', 'Nenhum cmentrios');
@define('POSTED_BY', 'Enviado por');
@define('ON', 'em');
@define('A_NEW_COMMENT_BLAHBLAH', 'Um novo comentrio foi enviado para o seu Blog "%s", no artigo intitulada como "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'Um novo trackback foi feito para o seu Blog "%s", no artigo intitulada como "%s".');
@define('NO_CATEGORY', 'Nenhuma categoria');
@define('ENTRY_BODY', 'Corpo do artigo');
@define('EXTENDED_BODY', 'Extenso do corpo do artigo');
@define('CATEGORY', 'Categoria:');
@define('EDIT', 'Editar');
@define('NO_ENTRIES_BLAHBLAH', 'Nenhum artigo encontrada para a consulta %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Sua busca para %s retornou %s resultados:');
@define('IMAGE', 'Imagem');
@define('ERROR_FILE_NOT_EXISTS', 'Erro: O nome de arquivo antigo no existe!');
@define('ERROR_FILE_EXISTS', 'Erro: O novo nome de arquivo j existe, escolha outro!');
@define('ERROR_SOMETHING', 'Erro: Problema desconhecido.');
@define('ADDING_IMAGE', 'Adicionando imagem...');
@define('THUMB_CREATED_DONE', 'Miniatura criada.<br>Pronto.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Erro: Arquivo j existe em sua mquina!');
@define('GO', 'Vai!');
@define('NEWSIZE', 'Novo tamanho: ');
@define('RESIZE_BLAHBLAH', '<b>Redimensionar %s</b><p>');
@define('ORIGINAL_SIZE', 'Tamanho original: <i>%sx%s</i> pixel');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Aqui voc pode ajustar o novo tamanho das imagens. Se pretende manter as propores, preencha apenas um valor e pressione a tecla TAB que automaticamente ser calculado o novo tamanho de modo que as propores no fiquem bagunadas:');
@define('QUICKJUMP_CALENDAR', 'Calendrio de acesso rpido');
@define('QUICKSEARCH', 'Pesquisa rpida');
@define('SEARCH_FOR_ENTRY', 'Procure por um artigo');
@define('ARCHIVES', 'Arquivos');
@define('BROWSE_ARCHIVES', 'Navegar nos arquivos por ms');
@define('TOP_REFERRER', 'Maiores Referncias');
@define('SHOWS_TOP_SITES', 'Exibe os links de entrada mais utilizados para entrar no seu blog');
@define('TOP_EXITS', 'Maiores Sadas');
@define('SHOWS_TOP_EXIT', 'Exibe os links de sada mais requisitados de seu blog');
@define('SYNDICATION', 'Sindicalizao');
@define('SHOWS_RSS_BLAHBLAH', 'Shows RSS syndication links');
@define('ADVERTISES_BLAHBLAH', 'Adverte da origem do seu blog');
@define('HTML_NUGGET', 'Fragmento de HTML');
@define('HOLDS_A_BLAHBLAH', 'Apresenta um fragmento de HTML  sua barra lateral');
@define('TITLE_FOR_NUGGET', 'Ttulo para o fragmento de HTML');
@define('THE_NUGGET', 'Fragmento de HTML!');
@define('SYNDICATE_THIS_BLOG', 'Sindicalizar esse Blog');
@define('YOU_CHOSE', 'Sua escolha %s');
@define('IMAGE_SIZE', 'Tamanho da imagem');
@define('IMAGE_AS_A_LINK', 'Insero de imagem');
@define('POWERED_BY', 'Powered by');
@define('TRACKBACKS', 'Trackbacks');
@define('TRACKBACK', 'Trackback');
@define('NO_TRACKBACKS', 'Nenhum Trackbacks');
@define('TOPICS_OF', 'Tpicos de');
@define('VIEW_FULL', 'ver tudo');
@define('VIEW_TOPICS', 'ver tpicos');
@define('AT', 'em');
@define('SET_AS_TEMPLATE', 'Atribuir como template');
@define('IN', 'no');
@define('EXCERPT', 'Segmento');
@define('TRACKED', 'Tracked');
@define('LINK_TO_ENTRY', 'Link para o artigo');
@define('LINK_TO_REMOTE_ENTRY', 'Link para artigo remoto');
@define('IP_ADDRESS', 'Endereo IP');
@define('USER', 'Usurio');
@define('THUMBNAIL_USING_OWN', 'Usando %s como sua prpria miniatura devido ao seu pequeno tamanho.');
@define('THUMBNAIL_FAILED_COPY', 'A tentativa de usar %s como sua prpria miniatura falhou devido  um erro na cpia!');
@define('AUTHOR', 'Autor');
@define('LAST_UPDATED', 'ltima atualizao');
@define('TRACKBACK_SPECIFIC', 'URI especfica do trackback para este artigo');
@define('DIRECT_LINK', 'Link direto para este artigo');
@define('COMMENT_ADDED', 'Seu comentrio foi adicionado corretamente. ');
@define('COMMENT_ADDED_CLICK', 'Clique %saqui para retornar%s aos comentrios, ou %saqui para fechar%s esta janela.');
@define('COMMENT_NOT_ADDED_CLICK', 'Clique %saqui para retornar %s aos comentrios, ou %saqui para fechar%s esta janela.');
@define('COMMENTS_DISABLE', 'No se permite comentrios para este artigo');
@define('COMMENTS_ENABLE', 'Comentrios para este artigo so permitidos');
@define('COMMENTS_CLOSED', 'O autor no autorizou comentrios para este artigo');
@define('EMPTY_COMMENT', 'Seu comentrio est vazio, por favor, %svolte%s e tente novamente');
@define('ENTRIES_FOR', 'Artigos para %s');
@define('DOCUMENT_NOT_FOUND', 'O documento %s no foi encontrado.');
@define('USERNAME', 'Usurio');
@define('PASSWORD', 'Senha');
@define('AUTOMATIC_LOGIN', 'Salvar informaes');
@define('SERENDIPITY_INSTALLATION', 'Instalao do Serendipity');
@define('LEFT', 'esquerda');
@define('RIGHT', 'direita');
@define('HIDDEN', 'oculto');
@define('REMOVE_TICKED_PLUGINS', 'Remover plugins marcados');
@define('SAVE_CHANGES_TO_LAYOUT', 'Salvar modificaes ao layout');
@define('COMMENTS_FROM', 'Comentrios de');
@define('ERROR', 'Erro');
@define('ENTRY_SAVED', 'Artigo salvo');
@define('DELETE_SURE', 'Tem certeza que deseja excluir #%s definitivamente?');
@define('NOT_REALLY', 'No mesmo...');
@define('DUMP_IT', 'Suma com ele!');
@define('RIP_ENTRY', 'At nunca mais artigo #%s');
@define('CATEGORY_DELETED', 'Categoria #%s excluda. Os artigos antigos foram movidos para a categoria #%s');
@define('INVALID_CATEGORY', 'Nenhuma categoria fornecida para excluso');
@define('CATEGORY_SAVED', 'Categoria salva');
@define('SELECT_TEMPLATE', 'Selecione o modelo desejado para o seu Blog');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'Artigos no adicionados!');
@define('YES', 'Sim');
@define('NO', 'No');
@define('USE_DEFAULT', 'Default');
@define('CHECK_N_SAVE', 'Verificar &amp; salvar');
@define('DIRECTORY_WRITE_ERROR', 'No foi possvel escrever no diretrio %s. Verifique as permisses.');
@define('DIRECTORY_CREATE_ERROR', 'O Diretrio %s no existe e no pode ser criado. Tente cri-lo manualmente');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; execute <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'No pde executar o binrio %s');
@define('FILE_WRITE_ERROR', 'No foi possvel editar o arquivo %s.');
@define('FILE_CREATE_YOURSELF', 'Por favor, crie voc mesmo o arquivo ou verifique suas permisses');
@define('COPY_CODE_BELOW', '<br />* Copie o cdigo abaixo e o coloque em %s no seu %s diretrio:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Altere www para o usurio com o qual o apache  executado (ex.: nobody).');
@define('BROWSER_RELOAD', 'Uma vez feito isso, pressione o boto "atualizar" ("reload") do seu navegador.');
@define('DIAGNOSTIC_ERROR', 'Detectamos alguns erros quando verificamos as informaes fornecidas por voc:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity ainda no est instalado. Por favor <a href="%s">instale-o</a> agora.');
@define('INCLUDE_ERROR', 'erro do serendipity: no foi possvel incluir %s - abortando.');
@define('DATABASE_ERROR', 'erro do serendipity: no foi possvel conectar ao banco de dados - abortando.');
@define('CREATE_DATABASE', 'Criando a instalao padro do banco de dados...');
@define('ATTEMPT_WRITE_FILE', 'Tentando editar o arquivo %s...');
@define('WRITTEN_N_SAVED', 'Configurao escrita &amp; salva');
@define('IMAGE_ALIGNMENT', 'Alinhamento de imagem');
@define('ENTER_NEW_NAME', 'Informe o novo nome para: ');
@define('RESIZING', 'Redimensionando');
@define('RESIZE_DONE', 'Pronto (%s imagens redimensionadas).');
@define('SYNCING', 'Sincronizando o banco de dados com o diretrio de imagens');
@define('SYNC_DONE', 'Pronto (%s imagens sincronizadas).');
@define('DELETE_IMAGE_FAIL' , 'No foi possvel excluir a imagem <b>%s</b>');
@define('DELETE_THUMBNAIL', 'Excluir a miniatura da imagem intitulada <b>%s</b>');
@define('FILE_NOT_FOUND', 'No foi possvel localizar o arquivo intitulado <b>%s</b>, ser que foi excludo?');
@define('ABORT_NOW', 'Cancelar agora');
@define('REMOTE_FILE_NOT_FOUND', 'O arquivo no foi localizado no servidor, tem certeza sobre a URL: <b>%s</b> est correta?');
@define('FILE_FETCHED', '%s buscado como %s');
@define('FILE_UPLOADED', 'O arquivo %s foi transferido corretamente: %s');
@define('WORD_OR', 'Ou');
@define('SCALING_IMAGE', 'Redimensionando %s para %s x %s px');
@define('KEEP_PROPORTIONS', 'Manter propores');
@define('REALLY_SCALE_IMAGE', 'Quer mesmo redimensionar a imagem? No haver volta!!');
@define('TOGGLE_ALL', 'Alternar para expandir tudo');
@define('TOGGLE_OPTION', 'Opo para alternar');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Inscrever-se para este artigo');
@define('UNSUBSCRIBE_OK', "%s teve a inscrio cancelada para este artigo");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Novo comentrio para o artigo inscrita"%s"');
@define('SUBSCRIPTION_MAIL', "Oi %s,\n\nUm novo comentrio foi feito num artigo que voc est monitorando em \"%s\", intitulada \"%s\"\nQuem enviou o comentrio foi: %s\n\nO artigo  qual nos referimos pode ser encontrada em: %s\n\nVoc pode cancelar sua inscrio clicando neste link: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Oi %s,\n\nUm novo trackback foi adicionado num artigo que voc est monitorando em \"%s\", intitulada \"%s\"\nQuem enviou o comentrio foi: %s\n\nO artigo  qual nos referimos pode ser encontrada em: %s\n\nVoc pode cancelar sua inscrio clicando neste link: %s\n");
@define('SIGNATURE', "\n-- \n%s faz uso do Serendipity.\nO melhor Blog que tem por a, e voc tambm pode us-lo.\nD uma olhada em <http://s9y.org> para descobrir como.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 feed');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 feed');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 feed');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 comments');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 feed');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Campo "managingEditor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Campo "webMaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Imagem para o RSS feed');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Largura da imagem');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Altura da imagem');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'E-Mail do webmaster, se disponvel. (vazio: oculto) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'E-Mail do editor, se disponvel. (vazio: oculto) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL de uma imagem no formato GIF/JPEG/PNG, se disponvel. (vazio: logotipo do serendipity)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'em pixels, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'em pixels, max. 400');
@define('SYNDICATION_PLUGIN_TTL', 'Campo "ttl" (tempo de vida)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Quantidade de minutos depois do qual seu blog no dever ser mais "cacheados" por sites/aplicaes (vazio: oculto) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Campo "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'O campo "pubDate" deve ser empacotado para o canal RSS, para mostrar a data do ltimo artigo?');
@define('CONTENT', 'Contedo');
@define('TYPE', 'Tipo');
@define('DRAFT', 'Rascunho');
@define('PUBLISH', 'Publicar');
@define('PREVIEW', 'Pr-visualizao');
@define('DATE', 'Data');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'Ateno: A data que voc especificou  invlida. Ela deve ser fornecida no formato DD/MM/AAAA HH:MM.');
@define('CATEGORY_PLUGIN_DESC', 'Exibe a lista de categorias.');
@define('ALL_AUTHORS', 'Todos autores');
@define('CATEGORIES_TO_FETCH', 'Categorias para trazer');
@define('CATEGORIES_TO_FETCH_DESC', 'Trazer categorias de qual autor?');
@define('PAGE_BROWSE_ENTRIES', 'Pgina %s de %s, totalizando %s artigos');
@define('PREVIOUS_PAGE', 'pgina anterior');
@define('NEXT_PAGE', 'prxima pgina');
@define('ALL_CATEGORIES', 'Todas as categorias');
@define('DO_MARKUP', 'Executar trasnformaes de marcao');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Formatao de data');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Formato da data atual do artigo, usando a mesma formatao da funo strftime() do PHP. (Padro: "%s")');
@define('ERROR_TEMPLATE_FILE', 'No foi possvel abrir o arquivo de template, por favor atualize o serendipity!');
@define('ADVANCED_OPTIONS', 'Opes avanadas');
@define('EDIT_ENTRY', 'Editar artigo');
@define('HTACCESS_ERROR', 'Para checar a instalao do servidor web, serendipity precisa ter poder criar o arquivo ".htaccess". Isso no foi possvel devido a erros de permisses. Por favor, ajuste as permisses para isso: <br />&nbsp;&nbsp;%s<br />e recarregue esta pgina.');
@define('SIDEBAR_PLUGINS', 'Plugins da barra lateral');
@define('EVENT_PLUGINS', 'Plugins de eventos');
@define('SORT_ORDER', 'Ordenao');
@define('SORT_ORDER_NAME', 'Nome do arquivo');
@define('SORT_ORDER_EXTENSION', 'Extenso do arquivo');
@define('SORT_ORDER_SIZE', 'Tamanho do arquivo');
@define('SORT_ORDER_WIDTH', 'Largura da imagem');
@define('SORT_ORDER_HEIGHT', 'Altura da imagem');
@define('SORT_ORDER_DATE', 'Data de transferncia');
@define('SORT_ORDER_ASC', 'Ascendente');
@define('SORT_ORDER_DESC', 'Descendente');
@define('THUMBNAIL_SHORT', 'Miniatura');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', 'Aplicar marcao para %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Comeo da semana');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity detectou que sua configurao est instalada com a verso %s, entretanto serendipity est instalado na verso %s, voc precisa atualizar o serendipity! <a href="%s">Clique aqui</a>');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Oi, e bem-vindo ao agente de atualizao do Serendipity.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Estou aqui para ajud-lo a atualizar a instalao %s do seu Serendipity.');
@define('SERENDIPITY_UPGRADER_WHY', 'Voc enxerga esta mensagem porque acabou de instalar o Serendipity %s, mas ainda no atualizou a instalao do banco de dados para compatibilizar com esta verso');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Atualizao do banco de dados (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'Encontrei os seguintes arquivos .sql u]que precisam ser executados antes que voc prossiga com a utilizao normal do Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Tarefas especficas da verso');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'Nenhuma tarefa especfica da verso foi encontrada');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Quer realizar as tarefas acima?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'No, eu as executarei manualmente');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Por favor, faa isso');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'Parece que que voc no precisa executar nenhuma atualizao');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Considere a atualizao do Serendipity');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'Voc ignorou a fase de atualizao do Serendipity, certifique-se de que o banco de dados est instalado corretamente e que as funes necessrias foram executadas');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'A sua instalao do Serendipity foi atualizada para a verso %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Voc pode retornar ao seu blog clicando %saqui%s');

@define('MANAGE_USERS', 'Gerenciar usurios');
@define('CREATE_NEW_USER', 'Criar novo usurio');
@define('CREATE_NOT_AUTHORIZED', 'Voc no pode modificar usurios que tenham o mesmo nvel que o seu');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'Voc no pode criar usurios com um nvel maior que o seu');
@define('CREATED_USER', 'Um novo usurio %s foi criado');
@define('MODIFIED_USER', 'As propriedades do usurio %s foram alteradas');
@define('USER_LEVEL', 'Nvel do usurio');
@define('DELETE_USER', 'Voc est prestes a excluir o usurio #%d %s. Tem certeza disso? Isso far com que os artigos escritos por ele no sejam mais exibidos.');
@define('DELETED_USER', 'Usurio #%d %s excludo.');
@define('LIMIT_TO_NUMBER', 'Quantos itens devem ser exibidos?');
@define('ENTRIES_PER_PAGE', 'artigos por pgina');
@define('XML_IMAGE_TO_DISPLAY', 'Boto XML');
@define('XML_IMAGE_TO_DISPLAY_DESC','Links para XML Feeds sero exibidos por esta imagem. Deixe em branco para padro, digite \'none\' para desabilitar.');

@define('DIRECTORIES_AVAILABLE', 'Na lista de subdiretrios disponveis voc pode clicar em qualquer nome de diretrio para criar um novo diretrio dentro daquela estrutura.');
@define('ALL_DIRECTORIES', 'todos os diretrios');
@define('MANAGE_DIRECTORIES', 'Gerenciar diretrios');
@define('DIRECTORY_CREATED', 'Diretrio <strong>%s</strong> foi criado.');
@define('PARENT_DIRECTORY', 'Diretrio superior');
@define('CONFIRM_DELETE_DIRECTORY', 'Tem certeza que quer excluir todo o contedo do diretrio %s?');
@define('ERROR_NO_DIRECTORY', 'Erro: Diretrio %s no existe');
@define('CHECKING_DIRECTORY', 'Verificando arquivos no diretrio %s');
@define('DELETING_FILE', 'Excluindo arquivo %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'No foi possvel remover um diretrio que no esteja vazio. Marque a opo "forar excluso" se deseja remover seus arquivos tambm, e envie o comando novamente. Os arquivos existenntes so:');
@define('DIRECTORY_DELETE_FAILED', 'A excluso do diretrio %s falhou. Verifique permisses ou as mensagem acima.');
@define('DIRECTORY_DELETE_SUCCESS', 'Diretrio %s excludo corretamente.');
@define('SKIPPING_FILE_EXTENSION', 'Ignorando arquivo: Faltando extenso em %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Ignorando arquivo: %s ilegvel.');
@define('FOUND_FILE', 'Encontrado arquivo novo/modificado: %s.');
@define('ALREADY_SUBCATEGORY', '%s j  uma subcategoria de %s.');
@define('PARENT_CATEGORY', 'Categoria superior');
@define('IN_REPLY_TO', 'Em reposta ');
@define('TOP_LEVEL', 'Nvel mximo');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
@define('PERMISSIONS', 'Permisses');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Configuraes de banco de dados');
@define('INSTALL_CAT_DB_DESC', 'Aqui voc pode inserir todas as informaes do seu banco de dados. O Serendipity precisa dessas informaes para funcionar.');
@define('INSTALL_DBTYPE', 'Tipo de banco de dados');
@define('INSTALL_DBTYPE_DESC', 'Tipo de banco de dados');
@define('INSTALL_DBHOST', 'Servidor de banco de dados');
@define('INSTALL_DBHOST_DESC', 'Endereo/Nome do seu servidor de banco de dados');
@define('INSTALL_DBUSER', 'Usurio de banco de dados');
@define('INSTALL_DBUSER_DESC', 'O nome de usurio que conecta ao banco');
@define('INSTALL_DBPASS', 'Senha do banco de dados');
@define('INSTALL_DBPASS_DESC', 'A senha correspondente ao usurio acima');
@define('INSTALL_DBNAME', 'Nome do banco de dados');
@define('INSTALL_DBNAME_DESC', 'O nome do banco de dados');
@define('INSTALL_DBPREFIX', 'Prefixo para as tabelas do banco de dados');
@define('INSTALL_DBPREFIX_DESC', 'Prefixo utilizado para nomear as tabelas, ex.: serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'Caminhos');
@define('INSTALL_CAT_PATHS_DESC', 'Os vrios caminhos para pastas e arquivos essnciais. No se esquea de terminar com barras para os diretrios');
@define('INSTALL_FULLPATH', 'Caminho completo');
@define('INSTALL_FULLPATH_DESC', 'O caminho completo e absoluto para a sua instalao do serendipity');
@define('INSTALL_UPLOADPATH', 'Caminho para o Upload');
@define('INSTALL_UPLOADPATH_DESC', 'Todos os arquivos transferidos iro parar a, relativo ao \'Caminho completo\' - geralmente \'uploads/\'');
@define('INSTALL_RELPATH', 'Caminho relativo');
@define('INSTALL_RELPATH_DESC', 'Caminho para o serendipity em seu navegador, geralmente \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Caminho relativo do template');
@define('INSTALL_RELTEMPLPATH_DESC', 'Caminho para o diretrio onde esto os seus templates - Relativo ao \'caminho relativo\'');
@define('INSTALL_RELUPLOADPATH', 'Caminho relativo do Upload');
@define('INSTALL_RELUPLOADPATH_DESC', 'Caminho para o \'uploads\' em seu navegador - Relativo ao \'caminho relativo\'');
@define('INSTALL_URL', 'URL do blog');
@define('INSTALL_URL_DESC', 'URL base para a instalao do serendipity');
@define('INSTALL_INDEXFILE', 'Arquivo inicial');
@define('INSTALL_INDEXFILE_DESC', 'Nome do arquivo inicial do serendipity');

/* Generel settings */
@define('INSTALL_CAT_SETTINGS', 'Configuraes gerais');
@define('INSTALL_CAT_SETTINGS_DESC', 'Padroniza como o Serendipity deve se comportar');
@define('INSTALL_USERNAME', 'Usurio do administrador');
@define('INSTALL_USERNAME_DESC', 'Nome de usurio para o login do administrador');
@define('INSTALL_PASSWORD', 'Senha do administrador');
@define('INSTALL_PASSWORD_DESC', 'Senha para o login do administrador');
@define('INSTALL_EMAIL', 'E-mail do administrador');
@define('INSTALL_EMAIL_DESC', 'E-mail do administrador do blog');
@define('INSTALL_SENDMAIL', 'Enviar e-mails ao administrador?');
@define('INSTALL_SENDMAIL_DESC', 'Voc deseja receber notificaes via e-mail quando novos comentrios forem includos em seus artigos?');
@define('INSTALL_SUBSCRIBE', 'Permitir que usurios se inscrevam nos artigos?');
@define('INSTALL_SUBSCRIBE_DESC', 'Permitir que usurios se inscrevam nos artigos e com isso, recebam notificaes via e-mail quando novos comentrios forem adicionados?');
@define('INSTALL_BLOGNAME', 'Nome do Blog');
@define('INSTALL_BLOGNAME_DESC', 'Ttulo do seu Blog');
@define('INSTALL_BLOGDESC', 'Descrio do Blog');
@define('INSTALL_BLOGDESC_DESC', 'Descrio');
@define('INSTALL_LANG', 'Idioma');
@define('INSTALL_LANG_DESC', 'Selecione o idioma para o seu blog');

/* Appearance and options */
@define('INSTALL_CAT_DISPLAY', 'Aparncia e opes');
@define('INSTALL_CAT_DISPLAY_DESC', 'Padroniza como o Serendipity  exibido');
@define('INSTALL_WYSIWYG', 'Usar editor WYSIWYG');
@define('INSTALL_WYSIWYG_DESC', 'Voc quer usar o editor WYSIWYG? (Funciona no IE5+ e parcialmente no Mozilla 1.3+)');
@define('INSTALL_XHTML11', 'Forar adequao ao XHTML 1.1');
@define('INSTALL_XHTML11_DESC', 'Quer forar uma adequao ao padro XHTML 1.1 (pode causar problemas de exibio nos navegadores de 4 gerao (4.x))');
@define('INSTALL_POPUP', 'Habilitar o uso de janelas popups');
@define('INSTALL_POPUP_DESC', 'Voc quer que o weblog utilize janelas popups para comentrios, trackbacks e etc?');
@define('INSTALL_EMBED', 'O serendipity est integrado?');
@define('INSTALL_EMBED_DESC', 'Se voc quer empacotar o serendipity em um website, mude para verdadeiro para descartar quaisquer cabealhos e apenas imprimir o contedo. Voc pode fazer uso da opo \'Arquivo inicial\' para usar uma classe mais abrangente onde voc colocaria os cabealhos normais de sua pgina. Veja o arquivo README para mais informaes!');
@define('INSTALL_BLOCKREF', 'Referncias bloqueadas');
@define('INSTALL_BLOCKREF_DESC', 'Existem servidores especiais que voc no gostaria de listar na sua lista de referncias? Separe a lista dos servidores com \';\' e note que o servidor ser bloqueado por uma busca parcial em sua string!');
@define('INSTALL_REWRITE', 'Rescrita de URL');
@define('INSTALL_REWRITE_DESC', 'Selecione as regras que voc gostaria de usar na gerao de URLs. A habilitao da reescrita de URL criar URLS bem formatadas para o seu blog e o deixar melhor indexvel para bots como o do google. O servidor web precisa dar suporte ou ao mod_rewrite ou ao "AllowOverride All" para o diretrio do seu serendipity. A configurao padro  auto detectada');

/* Imageconversion Settings */
@define('INSTALL_CAT_IMAGECONV', 'Configuraes da converso de imagens');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Informaes gerais sobre como o serendipity deve lidar com imagens');
@define('INSTALL_IMAGEMAGICK', 'Usar Imagemagick');
@define('INSTALL_IMAGEMAGICK_DESC', 'Voc tem o \'image magick\' instalado e quer utiliz-lo para redimensionar imagens?');
@define('INSTALL_IMAGEMAGICKPATH', 'Caminho para o executvel do conversor');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Caminho completo e nome do executvel do image magick');
@define('INSTALL_THUMBSUFFIX', 'Sufixo das miniaturas');
@define('INSTALL_THUMBSUFFIX_DESC', 'As miniaturas sero nomeadas com o seguinte formato: original.[sufixo].ext');
@define('INSTALL_THUMBWIDTH', 'Dimenso das miniaturas ');
@define('INSTALL_THUMBWIDTH_DESC', 'Largura mxima esttica das miniaturas geradas automaticamente');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Detalhes pessoais');
@define('USERCONF_CAT_PERSONAL_DESC', 'Altere os seus detalhes pessoais');
@define('USERCONF_USERNAME', 'Seu nome de usurio');
@define('USERCONF_USERNAME_DESC', 'O nome de usurio que voc usa para se identificar no blog');
@define('USERCONF_PASSWORD', 'Sua senha');
@define('USERCONF_PASSWORD_DESC', 'A senha que voc quer usar para se identificar no blog');
@define('USERCONF_EMAIL', 'Seu endereo de e-mail');
@define('USERCONF_EMAIL_DESC', 'Seu endereo de e-mail pessoal');
@define('USERCONF_SENDCOMMENTS', 'Enviar notificao dos comentrios?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Quer receber e-mails quando comentrios forem enviados para os seus artigos?');
@define('USERCONF_SENDTRACKBACKS', 'Enviar notificao de trackbacks?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Quer receber e-mails quando trackbacks forem enviados para os seus artigos?');
@define('USERCONF_ALLOWPUBLISH', 'Direitos: Publicao de artigos?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'Este usurio est autorizado a publicar artigos?');
@define('SUCCESS', 'Sucesso');
@define('POWERED_BY_SHOW_TEXT', 'Exibir "Serendipity" como texto');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Exibir o "Serendipity Weblog" como texto');
@define('POWERED_BY_SHOW_IMAGE', 'Exibir "Serendipity" como um logotipo');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Exibe o logotipo do Serendipity');

@define('SETTINGS_SAVED_AT', 'As novas configuraes foram salvas em %s');
@define('PLUGIN_ITEM_DISPLAY', 'Onde o item deve ser exibido?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Apenas artigo extendido');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'Pgina de viso geral apenas');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'Todas as vezes');
@define('RSS_IMPORT_CATEGORY', 'Utilize essa categoria para artigos que no encontrem uma categoria no Serendipity');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Ocorreu um erro desconhecido, o arquivo no foi transferido. Talvez o tamanho do arquivo seja maior que o permitido pelo seu servidor. Verifique com o seu servidor de Internet, ou edite o php.ini para permitir transferncia de arquivos de maior tamanho.');
@define('COMMENTS_WILL_BE_MODERATED', 'Comentrios enviados estaro sujeitos a moderao antes de serem exibidos.');
@define('YOU_HAVE_THESE_OPTIONS', 'Voc possui as seguintes opes disponveis');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Ateno: Esse comentrio precisa de aprovao antes que seja exibido');
@define('DELETE_COMMENT', 'Excluir comentrio');
@define('APPROVE_COMMENT', 'Aprovar comentrio');
@define('REQUIRES_REVIEW', 'Requer reviso');
@define('COMMENT_APPROVED', 'Comentrio #%s foi aprovado corretamente');
@define('COMMENT_DELETED', 'Comentrio #%s foi excludo corretamente');
@define('VIEW', 'Exibir');
@define('COMMENT_ALREADY_APPROVED', 'Comentrio #%s parece j ter sido aprovado');
@define('COMMENT_EDITED', 'O comentrio selecionado foi editado');
@define('HIDE', 'Ocultar');
@define('VIEW_EXTENDED_ENTRY', 'Continuar lendo "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Esse link no deve ser clicado. Ele contm a URI de trackback para este artigo. Voc pode usar esse URI para enviar ping- & trackbacks do seu prprio weblog para esse artigo. Para copiar o link, clique com o boto direito e selecione "Copiar Atalho" no Internet Explorer ou "Copiar localizao do link" no Mozilla.');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Ateno: Esse trackback precisa de aprovao antes que seja exibido');
@define('DELETE_TRACKBACK', 'Excluir trackback');
@define('APPROVE_TRACKBACK', 'Aprovar trackback');
@define('TRACKBACK_APPROVED', 'O trackback #%s foi aprovado corretamente');
@define('TRACKBACK_DELETED', 'O trackback #%s foi excludo corretamente');
@define('COMMENTS_MODERATE', 'Comentrios & trackbacks para este artigo requerem moderao');
@define('PLUGIN_SUPERUSER_HTTPS', 'Usar https para login');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Permitir o link de login aponte para uma link https. seu servidor web precisa ter suporte a isso!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Tornar clicveis os links externos?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"no": Links externos no marcados (Maiores sadas, Maiores referncias, Comentrios de usurios) no so exibidos como puro texto para evitar spam do google (recomendado). "sim": Links externos no marcados so exibidos como links. Podem ser sobrescritos pela configurao da barra lateral!');
@define('PAGE_BROWSE_COMMENTS', 'Pgina %s de %s, totalizando %s comentrios');
@define('FILTERS', 'Filtros');
@define('FIND_ENTRIES', 'Encontrar artigos');
@define('FIND_COMMENTS', 'Encontrar comentrios');
@define('FIND_MEDIA', 'Encontrar mdia');
@define('FILTER_DIRECTORY', 'Diretrio');
@define('SORT_BY', 'Ordenar por');
@define('TRACKBACK_COULD_NOT_CONNECT', 'Nenhum trackback enviado: No foi possvel abrir conexo para %s na porta %d');
@define('MEDIA', 'Mdia');
@define('MEDIA_LIBRARY', 'Biblioteca de mdia');
@define('ADD_MEDIA', 'Adicionar mdia');
@define('ENTER_MEDIA_URL', 'Entre com a URL de um arquivo para busc-lo:');
@define('ENTER_MEDIA_UPLOAD', 'Selecione o arquivo que deseja transferir:');
@define('SAVE_FILE_AS', 'Salvar arquivo como:');
@define('STORE_IN_DIRECTORY', 'Guardar no seguinte diretrio: ');
@define('MEDIA_RENAME', 'Renomear esse arquivo');
@define('IMAGE_RESIZE', 'Redimensionar essa imagem');
@define('MEDIA_DELETE', 'Excluir esse arquivo');
@define('FILES_PER_PAGE', 'Arquivos por pgina');
@define('CLICK_FILE_TO_INSERT', 'Clique no arquivo que deseja inserir:');
@define('SELECT_FILE', 'Selecione arquivo para inserir');
@define('MEDIA_FULLSIZE', 'Tamanho total');
@define('CALENDAR_BOW_DESC', 'Dia da semana que deve ser considerado o incio da semana. Padro  segunda-feira');
@define('SUPERUSER', 'Administrao do weblog');
@define('ALLOWS_YOU_BLAHBLAH', 'Prov um link para a administrao do weblog na barra lateral ');
@define('CALENDAR', 'Calendrio');
@define('SUPERUSER_OPEN_ADMIN', 'Abrir administrao');
@define('SUPERUSER_OPEN_LOGIN', 'Abrir tela de login');
@define('INVERT_SELECTIONS', 'Inverter Seleo');
@define('COMMENTS_DELETE_CONFIRM', 'Tem certeza de que deseja excluir os comentrios selecionados?');
@define('COMMENT_DELETE_CONFIRM', 'Tem certeza de que deseja excluir o comentrio #%d, escrito por %s?');
@define('DELETE_SELECTED_COMMENTS', 'Excluir comentrios selecionados');
@define('VIEW_COMMENT', 'Exibir comentrio');
@define('VIEW_ENTRY', 'Exibir artigo');
@define('DELETE_FILE', 'Excluir o campo entitulado <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'Voc est prestes a excluir <b>%s</b><br />Se estiver utilizando esse arquivo em algum dos seus artigos, vai resultar em links ou imagens perdidas<br />Deseja realmente prosseguir com a excluso?<br /><br />');
@define('TRACKBACK_SENDING', 'Enviando trackback para a URI %s...');
@define('TRACKBACK_SENT', 'Trackback enviada com sucesso');
@define('TRACKBACK_FAILED', 'Trackback falhou: %s');
@define('TRACKBACK_NOT_FOUND', 'Nenhum URI de trackback foi encontrado.');
@define('TRACKBACK_URI_MISMATCH', 'A URI de trackback descoberta no com  semelhante  URI alvo.');
@define('TRACKBACK_CHECKING', 'Checando <u>%s</u> por possveis trackbacks...');
@define('TRACKBACK_NO_DATA', 'O alvo no contm dados');
@define('TRACKBACK_SIZE', 'URI alvo excedeu o tamanho mximo de %s bytes para um arquivo.');
@define('VIEWMODE_THREADED', 'Alternar para exibio por discusso');
@define('COMMENTS_VIEWMODE_THREADED', 'Discusso');
@define('COMMENTS_VIEWMODE_LINEAR', 'Seqencial');
@define('DISPLAY_COMMENTS_AS', 'Exibir comentrios como');
@define('DATE_FORMAT_SHORT', '%d/%m/%Y %H:%M');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', ',');
@define('NUMBER_FORMAT_THOUSANDS', '.');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Categoria #%s excluda. Os artigos antigos foram movidos para a categoria #%s');
@define('INSTALL_TOP_AS_LINKS', 'Exibir maiores sadas/referncias como links?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"no": Sadas e Referncias so exibidas como puro texto para prevenir spam do google. "sim": Sadas e Referncias so exibidas como links. "padro": Usa o valor definido na configurao global (recomendado).');
@define('ADD_MEDIA_BLAHBLAH', '<b>Adiciona um arquivo para o seu repositrio de mdia:</b><p>Aqui voc pode transferir arquivos de mdia, ou oriente-me para peg-lo em algum lugar na web! Se no possuir uma imagem apropriada, <a href="http://images.google.com" target="_blank">procure no google</a> alguma imagem que tenha relao com o assunto, os resultados so geralmente teis e divertidos :)</p><p><b>Selecione o mtodo:</b></p><br/>');
@define('COMMENTS_FILTER_SHOW', 'Mostrat');
@define('COMMENTS_FILTER_ALL', 'Todos');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Apenas os aprovados');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'Aprovaes pendentes');
@define('RSS_IMPORT_BODYONLY', 'Coloque todo o texto no "corpo" da seo e no divida em "sees extendidas".');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Mostrar artigos completos com corpo extendido dentro de um RSS');
@define('MT_DATA_FILE', 'Pasta de "Movable Type"');
@define('FORCE', 'Forar');
@define('CREATE_AUTHOR', 'Criar autor \'%s\'.');
@define('CREATE_CATEGORY', 'Criar categoria \'%s\'.');
@define('MYSQL_REQUIRED', 'Voc deve ter extenses MySQL para executar esta ao.');
@define('COULDNT_CONNECT', 'No foi possvel conectar a base de dados MySQL: %s.');
@define('COULDNT_SELECT_DB', 'No foi possvel selecionar a base de dados: %s.');
@define('COULDNT_SELECT_USER_INFO', 'No foi possvel selecionar informaes do usurio: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'No foi possvel selecionar informaes da categoria: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'No foi possvel selecionar informaes de entrada: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'No foi possvel selecionar informaes de comentrio: %s.');
@define('WEEK', 'Semana');
@define('WEEKS', 'Semanas');
@define('MONTHS', 'Meses');
@define('DAYS', 'Dias');
@define('ARCHIVE_FREQUENCY', 'Frequncia do tem do calendrio');
@define('ARCHIVE_FREQUENCY_DESC', 'Intervalo do calendrio para ser usado entre cada tem da lista');
@define('ARCHIVE_COUNT', 'Nmero de tens na lista');
@define('ARCHIVE_COUNT_DESC', 'Nmero total de meses, semanas e dias para mostrar');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Abaixo a lista dos plugins instalados');
@define('SIDEBAR_PLUGIN', 'barra lateral de plugins');
@define('EVENT_PLUGIN', 'plugin de eventos');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Clique aqui para instalar um novo %s');
@define('VERSION', 'verso');
@define('INSTALL', 'Instalar');
@define('ALREADY_INSTALLED', 'J instalado');
@define('SELECT_A_PLUGIN_TO_ADD', 'Selecione o plugin que voc deseja instalar');
@define('INSTALL_OFFSET', 'Offset temporal no servidor');
@define('STICKY_POSTINGS', 'Postagens fixas');
@define('INSTALL_FETCHLIMIT', 'Entradas que sero mostradas na primeira pgina');
@define('INSTALL_FETCHLIMIT_DESC', 'Nmeros de entradas para mostrar na primeira pgina');
@define('IMPORT_ENTRIES', 'Importar dados');
@define('EXPORT_ENTRIES', 'Exportar entradas');
@define('IMPORT_WELCOME', 'Bem vindo ao utilitrio de importao do Serendipity');
@define('IMPORT_WHAT_CAN', 'Aqui voc pode importar dados de outros aplicativos de weblog');
@define('IMPORT_SELECT', 'Selecione o software do qual est importando');
@define('IMPORT_PLEASE_ENTER', 'Por-favor insira os dados como solicitado abaixo');
@define('IMPORT_NOW', 'Importar agora!');
@define('IMPORT_STARTING', 'Iniciar procedimento de importao...');
@define('IMPORT_FAILED', 'Falha na importao');
@define('IMPORT_DONE', 'Importao completou com sucesso');
@define('IMPORT_WEBLOG_APP', 'Aplicao de weblog');
@define('EXPORT_FEED', 'Exportar todos os RSS');
@define('STATUS', 'Situao aps importao');
@define('IMPORT_GENERIC_RSS', 'Importao de RSS genrico');
@define('ACTIVATE_AUTODISCOVERY', 'Enviar Trackbacks de ligaes encontradas na entrada');
@define('WELCOME_TO_ADMIN', 'Bem vindo a suite de administrao do Serendipity.');
@define('PLEASE_ENTER_CREDENTIALS', 'Por Favor insira suas credenciais abaixo.');
@define('ADMIN_FOOTER_POWERED_BY', 'Desenvolvido por Serendipity %s e PHP %s');
@define('INSTALL_USEGZIP', 'Use pginas compactadas (gzip)');
@define('INSTALL_USEGZIP_DESC', 'Para que as pginas fiquem mais rpidas podemos compacta-las com gzip. Isso  recomendado, desde que o navegador do visitante suporte.');
@define('INSTALL_SHOWFUTURE', 'Mostrar entradas futuras');
@define('INSTALL_SHOWFUTURE_DESC', 'Habilitando esta escolha, todas as entradas no blog sero mostradas. O padro  ocultar estas entradas e s mostra-las na data de publicao.');
@define('INSTALL_DBPERSISTENT', 'Usar conexes persistentes');
@define('INSTALL_DBPERSISTENT_DESC', 'Habilitar o uso de conexes persistentes na base de dados, leia mais em <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">here</a>. Normalmente no recomendamos isso!');
@define('NO_IMAGES_FOUND', 'Nenhuma imagem encontrada');
@define('PERSONAL_SETTINGS', 'Preferncias Pessoais');
@define('REFERER', 'Referenciador');
@define('NOT_FOUND', 'No encontrado');
@define('NOT_WRITABLE', 'Sem permisso de escrita');
@define('WRITABLE', 'Com permisso de escrita');
@define('PROBLEM_DIAGNOSTIC', 'Foi diagnosticado um problema! voc no pode continuar com a instalao sem antes arrumar os erros abaixo');
@define('SELECT_INSTALLATION_TYPE', 'Selecione o tipo de instalao que voc deseja usar');
@define('WELCOME_TO_INSTALLATION', 'Bem-vindo a instalao do Serendipity');
@define('FIRST_WE_TAKE_A_LOOK', 'Primeiro vamos examinar sua instalao para verificar possveis erros e compatibilidades');
@define('ERRORS_ARE_DISPLAYED_IN', 'Os erros sero mostrados em %s, recomendaes em %s e sucesso em %s');
@define('RED', 'vermelho');
@define('YELLOW', 'amarelo');
@define('GREEN', 'verde');
@define('PRE_INSTALLATION_REPORT', 'Mensagens de  pr-instalao do Serendipity v%s');
@define('RECOMMENDED', 'Recomendado');
@define('ACTUAL', 'Atual');
@define('PHPINI_CONFIGURATION', 'configurao do php.ini');
@define('PHP_INSTALLATION', 'Instalao do PHP');
@define('THEY_DO', 'fazendo');
@define('THEY_DONT', 'no fazendo');
@define('SIMPLE_INSTALLATION', 'Instalao em modo "simples"');
@define('EXPERT_INSTALLATION', 'Instalao em modo "expert"');
@define('COMPLETE_INSTALLATION', 'Instalao completa');
@define('WONT_INSTALL_DB_AGAIN', 'no instale a base de dados novamente');
@define('CHECK_DATABASE_EXISTS', 'Verificando se as tabelas da base de dados j existem');
@define('CREATING_PRIMARY_AUTHOR', 'Criar author principal \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Aplicando modelo padro');
@define('INSTALLING_DEFAULT_PLUGINS', 'Instalando plugins padro');
@define('SERENDIPITY_INSTALLED', 'Serendipity foi instalado com sucesso');
@define('VISIT_BLOG_HERE', 'Acesse seu novo blog aqui');
@define('THANK_YOU_FOR_CHOOSING', 'Obrigado por escolher o Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'Foi detectado um erro na instalao');
@define('OPERATING_SYSTEM', 'Sistema Operacional');
@define('WEBSERVER_SAPI', 'Webserver SAPI');
@define('IMAGE_ROTATE_LEFT', 'Girar imagem 90 graus no sentido anti-horrio');
@define('IMAGE_ROTATE_RIGHT', 'Girar imagem 90 graus no sentido horrio');
@define('TEMPLATE_SET', '\'%s\' foi definido como seu modelo ativo');
@define('SEARCH_ERROR', 'A funo de pesquisa no funcionou como esperado. Informao ao administrador deste blog: isso pode ocorrer em funo da falta de um ndice na base de dados. No MySQL a conta do usurio precisa de privilgios para executar o comando: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> O erro especfico que a base de dados retornou foi: <pre>%s</pre>');
@define('EDIT_THIS_CAT', 'Editar "%s"');
@define('CATEGORY_REMAINING', 'Apague esta categoria e mova os dados para esta outra categoria');
@define('CATEGORY_INDEX', 'Abaixo, a lista de categorias disponveis das suas entradas');
@define('NO_CATEGORIES', 'Sem categorias');
@define('RESET_DATE', 'Reinicializar data');
@define('RESET_DATE_DESC', 'Clique aqui para reinicializar data para o valor corrente');
@define('PROBLEM_PERMISSIONS_HOWTO', 'As permisses do diretrio podem ser ajustadas rodando o comando `<em>%s</em>` no shell, ou usando um programa de FTP');
@define('WARNING_TEMPLATE_DEPRECATED', 'Ateno: seu modelo padro est usando um mtodo obsoleto, voc ser avisado para fazer uma atualizao se for possvel.');
@define('ENTRY_PUBLISHED_FUTURE', 'Esta entrada no foi publicada ainda.');
@define('ENTRIES_BY', 'Entradas por %s');
@define('PREVIOUS', 'Anterior');
@define('NEXT', 'Prximo');
@define('APPROVE', 'Aprovar');
@define('DO_MARKUP_DESCRIPTION', 'Aplicar transformaes de marcas no texto (carinhas, abreviaturas com *, /, _, ...). Desabilitando isso voc preservar o cdigo HTML no texto.');
@define('CATEGORY_ALREADY_EXIST', 'A categoria com o nome "%s" j existe');
@define('IMPORT_NOTES', 'Nota:');
@define('ERROR_FILE_FORBIDDEN', 'Voc no est autorizado a enviar arquivos com a pasta ativa');
@define('ADMIN', 'Administrao');
@define('ADMIN_FRONTPAGE', 'Pgina Inicial');
@define('QUOTE', 'Citar');
@define('IFRAME_SAVE', 'Serendipity est salvando suas entradas, criando trackbacks e verificando possveis chamadas em XML-RPC. Isso pode demorar um pouco..');
@define('IFRAME_SAVE_DRAFT', 'Um rascunho desta entrada foi arquivado');
@define('IFRAME_PREVIEW', 'Serendipity est criando uma previso de sua entrada...');
@define('IFRAME_WARNING', 'Seu navegador no suporta o conceito de "iframes". Por favor o arquivo serendipity_config.inc.php e configure a varivel $serendipity[\'use_iframe\'] para FALSE.');
@define('NONE', 'nenhum');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Configurao padro para novas entradas');
@define('UPGRADE', 'Atualizao');
@define('UPGRADE_TO_VERSION', 'Atualizao para a verso %s');
@define('DELETE_DIRECTORY', 'Apagar pasta');
@define('DELETE_DIRECTORY_DESC', 'Voc est apagando o contedo de um diretrio que contm arquivos multimdia, possivelmente usados em outras entradas.');
@define('FORCE_DELETE', 'Apagar TODOS os arquivos no diretrio, incluindo os no conhecidos pelo Serendipity');
@define('CREATE_DIRECTORY', 'Criar diretrio');
@define('CREATE_NEW_DIRECTORY', 'Criar novo diretrio');
@define('CREATE_DIRECTORY_DESC', 'Aqui voc pode criar um novo diretrio para armazenar arquivos multimdia. Escolha o nome da pasta e se preferir, escolha um diretrio de nvel superior para salvar sua pasta dentro.');
@define('BASE_DIRECTORY', 'Diretrio base');
@define('USERLEVEL_EDITOR_DESC', 'Editor');
@define('USERLEVEL_CHIEF_DESC', 'Editor Chefe');
@define('USERLEVEL_ADMIN_DESC', 'Administrador');
@define('USERCONF_USERLEVEL', 'Nvel de acesso');
@define('USERCONF_USERLEVEL_DESC', 'Este nvel ser usado para determinar que tipo de acesso os usurios tero em seu blog');
@define('USER_SELF_INFO', 'Conectado como %s (%s)');
@define('ADMIN_ENTRIES', 'Entradas');
@define('RECHECK_INSTALLATION', 'Verifique a instalao');
@define('IMAGICK_EXEC_ERROR', 'Impossvel executar: "%s", erro: %s, retornou varivel: %d');
@define('INSTALL_OFFSET_DESC', 'Informe a diferena de horas entre a data do seu servidor (current: %clock%) e o fuso horrio que deseja');
@define('UNMET_REQUIREMENTS', 'Requisitos falharam: %s');
@define('CHARSET', 'Codificao de Caracteres');
@define('AUTOLANG', 'Usar a linguagem padro do navegador do visitante');
@define('AUTOLANG_DESC', 'Marcada esta opo ela ir ativar as configuraes de linguagem apartir da linguagem padro do navegador do visitante.');
@define('INSTALL_AUTODETECT_URL', 'Autodetectar usando HTTP-Host');
@define('INSTALL_AUTODETECT_URL_DESC', 'Se marcado "true", o Serendipity assegurar que o HTTP Host que  usado pelo seu visitante  usado como definio de BaseURL. Permitir isto possibilita usar vrios nomes de domnio para o seu blog, e usar o domnio para todos os links subseqentes.');
@define('CONVERT_HTMLENTITIES', 'Tentar auto-converter as entidades HTML?');
@define('EMPTY_SETTING', 'Voc no especificou um valor vlido para "%s"!');
@define('USERCONF_REALNAME', 'Nome real');
@define('USERCONF_REALNAME_DESC', 'Todo o nome do autor. Este nome  o que os leitores enxergam');
@define('HOTLINK_DONE', 'Arquivo entrelaado.<br />Feito.');
@define('ENTER_MEDIA_URL_METHOD', 'Mtodo de obteno:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Nota: se voc quer fazer um "hotlink" para um servidor, tenha certeza de ter permisses suficientes. Os "hotlinks" permitem que voc use ligaes em imagem no armazenadas no servidor local.');
@define('MEDIA_HOTLINKED', 'entrelaado');
@define('FETCH_METHOD_IMAGE', 'Baixar imagem para o servidor');
@define('FETCH_METHOD_HOTLINK', 'entrelaar externo ao servidor');
@define('DELETE_HOTLINK_FILE', 'Apagar o entrelaamento do arquivo de nome <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'Mostrar o endereo de e-mail?');
@define('IMAGE_MORE_INPUT', 'Adicionar mais imagens');
@define('BACKEND_TITLE', 'Informaes adicionais da tela de configurao de plugins');
@define('BACKEND_TITLE_FOR_NUGGET', 'Aqui voc pode definir um texto personalizado que aparecer na tela de configurao de plugin, junto com a descrio de HTML do plugin Nuggets. Se voc possui mltiplos HTML nuggets com nome em branco, isto ir ajudar a separar uns dos outros.');//verify
@define('CATEGORIES_ALLOW_SELECT', 'Permite aos visitantes mostrar mltiplas categorias ao mesmo tempo?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Se esta opo estiver ativa, uma caixa de seleo sr mostrada ao lado de cada categoria na barra lateral dos plugins. Os usurios podem marcar estas caixas de seleo e ver as entradas pertencentes a cada uma.');
@define('PAGE_BROWSE_PLUGINS', 'Paginas %s de %s, totalizando %s plugins.');
@define('INSTALL_CAT_PERMALINKS', 'Permalinks');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Defina vrias URLs padres quando definir os links permanentes do seu blog. Sugerimos isso como padro; caso contrrio, voc pode usar os valores %id% quando possvel para prevenir que Serendipity fique buscando na base de dados o URL.');//verificar
@define('INSTALL_PERMALINK', 'Estrutura de entrada das URLs de Permalink');
@define('INSTALL_PERMALINK_DESC', 'Aqui voc define a URL relativa da estrutura que inicia com a sua URL base onde as entradas esto definidas. Voc pode usar as variveis  %id%, %title%, %day%, %month%, %year% ou quaisquer outras.');
@define('INSTALL_PERMALINK_AUTHOR', 'Estrutura da URL do autor de Permalink');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Aqui voc pode definir as URLs relativas das estruturas que iniciam pela sua URL base onde algumas entradas de outros autores tornan-se disponveis. Voc pode usar as variveis %id%, %realname%, %username%, %email% ou quaisquer outros.');
@define('INSTALL_PERMALINK_CATEGORY', 'Estrutura da URL da categoria de permalink');

@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Aqui voc pode definir as estruturas URL relativas, iniciando pela sua URL base, de onde outras categorias se tornaro disponveis. Voc pode usar as variveis %id%, %name%, %description%, ou quaisquer outros.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Categoria das estruturas URL de Permalink e RSS-Feed');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Aqui voc pode definir as estruturas URL relativas, iniciando pela sua URL base at onde o RSS-feed se torna disponvel. Voc pode usar as variveis %id%, %name%, %description%, ou quaisquer outros.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Caminho para arquivos');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Caminho para arquivo');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Caminho para as categorias');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Caminho para subscrio de comentrios');
@define('INSTALL_PERMALINK_DELETEPATH', 'Caminho para comentrios apagados');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Caminho para comentrios aprovados');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Caminho para o RSS Feeds');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Caminho para plugin nico');
@define('INSTALL_PERMALINK_ADMINPATH', 'Caminho para administrao');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Caminho para pesquisa');
@define('INSTALL_CAL', 'Tipo de calendrio');
@define('INSTALL_CAL_DESC', 'Escolha o formato do calendrio desejado');
@define('REPLY', 'Responder');
@define('USERCONF_GROUPS', 'Inscries de grupos');
@define('USERCONF_GROUPS_DESC', 'Este usurio pertence ao(s) seguintes grupos.  possvel usar mltiplos usurios.');
@define('MANAGE_GROUPS', 'Gerenciar grupos');
@define('DELETED_GROUP', 'Grupo #%d %s apagado.');
@define('CREATED_GROUP', 'Um novo grupo %s foi criado');
@define('MODIFIED_GROUP', 'As propriedades do grupo %s foram mudadas');
@define('GROUP', 'Grupo');
@define('CREATE_NEW_GROUP', 'Criar novo grupo');
@define('DELETE_GROUP', 'Voc est prestes a apagar o grupo #%d %s. Realmente quer fazer isso?');
@define('USERLEVEL_OBSOLETE', 'NOTCIA: Os atributos de permisses e autorizao dos usurios esto sendo usados apenas por motivo de compatibilidade com os plugins. Os privilgios, a partir de agora, so geridos atravs das permisses dos grupos!');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'O ID do "feed" que voc deseja publicar');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner image');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Nome da imagem para mostrar (ou deixe em branco), localizado em feedburner.com, ex: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'Ttulo do FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Ttulo (se tiver) para mostrar ao lado da imagem');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'imagem texto FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Texto (se tiver) para mostrar pairando sobre a imagem');
@define('SEARCH_TOO_SHORT', 'Sua pesquisa precisa ter mais de trs caracteres. Voc pode tentar usar * quando for pesquisar com poucas letras, por exemplo: s9y* para enganar a pesquisa.');
@define('INSTALL_DBPORT', 'Porta do banco de dados');
@define('INSTALL_DBPORT_DESC', 'A porta usada para conectar seu servidor de banco de dados');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Pgina inicial: servios externos');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Pgina inicial: caractersticas');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Pgina inicial: modificaes "Mods"');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Pgina inicial: Vises');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Pgina inicial: relao de entradas');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Pgina posterior: editor');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Pgina posterior: gerenciamento de usurio');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Pgina posterior: meta informao');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Pgina posterior: modelos');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Pgina posterior:caractersticas');
@define('PLUGIN_GROUP_IMAGES', 'Imagens');
@define('PLUGIN_GROUP_ANTISPAM', 'Antispam');
@define('PLUGIN_GROUP_MARKUP', 'Marcao');
@define('PLUGIN_GROUP_STATISTICS', 'Estatsticas');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: Acesso as configuraes pessoais');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: Trocar nveis de usurios');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: Trocar "entradas proibidas"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: Trocar direitos de publicao das entradas');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Acesso a configurao do sistema');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Acesso a configurao do blog-centric');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: Administrar entradas');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: Adminitrar outras entradas de usurios');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Importar entradas');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: Administrar categorias');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: Administrar categorias de outros usurios');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: Apagar categorias');
@define('PERMISSION_ADMINUSERS', 'adminUsers: Administrar usurios');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: Apagar usurios');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: Mudar nvel de usurio');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: Administrar usurios(s) que esto em seu(s) grupo(s)');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: Administrar usurios que no esto no(s) seu(s) grupo(s)');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: Criar novos usurios');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: Administrar grupos de usurios');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: Administrar plugins');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: Administrar plugins de usurios ');
@define('PERMISSION_ADMINIMAGES', 'adminImages: Administrar arquivos multimdia');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: Administrar pastas de arquivos multimdia');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: Adicionar novos arquivos multimdia');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Apagar arquivos multimdia');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Administrar outros arquivos multimdia de usurio(s)');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: Ver arquivos multimdia');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Syncronizar miniaturas');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: Administrar comentrios');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Administrar modelos');
@define('INSTALL_BLOG_EMAIL', 'Endereos de e-mail do Blog');
@define('INSTALL_BLOG_EMAIL_DESC', 'Aqui  configurado o nome do usurio que ser usado nos e-mails de sada. Tenha certeza que este e-mail  reconhecido pelo servidor - muitos servidores rejeitam o envio caso no conheam quem est enviando.');
@define('CATEGORIES_PARENT_BASE', 'Mostre apenas as categorias abaixo...');
@define('CATEGORIES_PARENT_BASE_DESC', 'voc pode escolher uma categoria "pai" de forma que apenas as categorias "filhas" sejam mostradas.');
@define('CATEGORIES_HIDE_PARALLEL', 'Esconder categorias que no fazem parte da rvore de categorias');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Se voc quer esconder categorias que so partes diferentes da rvore de categorias, voc deve habilitar isso. Esta escolha faz mais sentido se voc usar junto com a opo "multi-blog" no "Propriedades/Categorias de modelos"');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: Visualizar arquivos multimdia de outros usurios');
@define('CHARSET_NATIVE', 'Cdigo de pgina nativo');
@define('INSTALL_CHARSET', 'Seleo do cdigo de pgina');
@define('INSTALL_CHARSET_DESC', 'Aqui voc pode escolher os cdigos de pgina entre o UTF-8 ou nativo (ISO, EUC, ...). Algumas linguagens apenas possuem tradues em UTF-8 ento a escolha por nativo no ter efeito. o UTF-8  sugerido para novas instalaes. No faa alteraes se voc j fez entradas com caracteres especiais - eles podem aparecer corrompidos. Para saber mais acesse http://www.s9y.org/index.php?node=46.');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Enable Plugin API hook');
@define('CALENDAR_EXTEVENT_DESC', 'If enabled, plugins can hook into the calendar to display their own events highlighted. Only enable if you have installed plugins that need this, otherwise it just decreases performance.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'The XML-RPC API Interface to Serendipity is no longer bundled because of ongoing security issues with this API and not many people using it. Thus you need to install the XML-RPC Plugin to use the XML-RPC API. The URL to use in your applications will NOT change - as soon as you have installed the plugin, you will again be able to use the API.');
@define('PERM_READ', 'Read permission');
@define('PERM_WRITE', 'Write permission');

@define('PERM_DENIED', 'Permission denied.');
@define('INSTALL_ACL', 'Apply read-permissions for categories');
@define('INSTALL_ACL_DESC', 'If enabled, the usergroup permission settings you setup for categories will be applied when logged-in users view your blog. If disabled, the read-permissions of the categories are NOT applied, but the positive effect is a little speedup on your blog. So if you don\'t need multi-user read permissions for your blog, disable this setting.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Configuration syntax wrong for option "%s". Needs content of type "%s".');
@define('USERCONF_CHECK_PASSWORD', 'Old Password');
@define('USERCONF_CHECK_PASSWORD_DESC', 'If you change the password in the field above, you need to enter the current user password into this field.');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'You did not specify the right old password, and are not authorized to change the new password. Your settings were not saved.');
@define('ERROR_XSRF', 'Your browser did not sent a valid HTTP-Referrer string. This may have either been caused by a misconfigured browser/proxy or by a Cross Site Request Forgery (XSRF) aimed at you. The action you requested could not be completed.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Here you can define the relative URL structure beginning from your base URL to where RSS-feeds from specific users may be viewed. You can use the variables %id%, %realname%, %username%, %email% and any other characters.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Permalink RSS-Feed Author URL structure');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'Path to authors');
@define('AUTHORS', 'Authors');
@define('AUTHORS_ALLOW_SELECT', 'Allow visitors to display multiple authors at once?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'If this option is enabled, a checkbox will be put next to each author in this sidebar plugin.  Users can check those boxes and see entries matching their selection.');
@define('AUTHOR_PLUGIN_DESC', 'Shows a list of authors');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Enable Smarty-Templates?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'If this option is enabled, the plugin will utilize Smarty-Templating features to output the category listing. If you enable this, you can change the layout via the "plugin_categories.tpl" template file. Enabling this option will impact performance, so if you do not need to make customizations, leave it disabled.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Show number of entries per category?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Show number of articles next to author name?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'If this option is enabled, the number of articles by this author is shown next to the authors name in parentheses.');
@define('CUSTOM_ADMIN_INTERFACE', 'Custom admin interface available');

@define('COMMENT_NOT_ADDED', 'Seus comentrios no foram adicionados, porque comentrios para este artigo foram desabilitadas. '); // Retranslate: 'Your comment could not be added, because comments for this entry have either been disabled, you entered invalid data, or your comment was caught by anti-spam measurements.'
@define('INSTALL_TRACKREF', 'Enable referrer tracking?');
@define('INSTALL_TRACKREF_DESC', 'Enabling the referrer tracking will show you which sites refer to your articles. Today this is often abused for spamming, so you can disable it if you want.');
@define('CATEGORIES_HIDE_PARENT', 'Hide the selected parent category?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'If you restrict the listing of categories to a specific category, by default you will see that parent category within the output listing. If you disable this option, the parent category name will not be displayed.');
@define('WARNING_NO_GROUPS_SELECTED', 'Warning: You did not select any group memberships. This would effectively log you out of the usergroup management, and thus your group memberships werde not changed.');
@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Number of entries to display for each page on the RSS Feed.');
@define('INSTAL_DB_UTF8', 'Enable DB-charset conversion');
@define('INSTAL_DB_UTF8_DESC', 'Issues a MySQL "SET NAMES" query to indicate the required charset for the database. Turn this on or off, if you see weird characters in your blog.');
@define('ONTHEFLYSYNCH', 'Enable on-the-fly media synchronization');
@define('ONTHEFLYSYNCH_DESC', 'If enabled, Serendipity will compare the media database with the files stored on your server and synchronize the database and directory contents.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'The username cannot be left blank.');
@define('FURTHER_LINKS', 'Further Links');
@define('FURTHER_LINKS_S9Y', 'Serendipity Homepage');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity Documentation');
@define('FURTHER_LINKS_S9Y_BLOG', 'Official Blog');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Forums');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Comment removed)');

@define('CURRENT_AUTHOR', 'Current author');

@define('WORD_NEW', 'New');
@define('SHOW_MEDIA_TOOLBAR', 'Show toolbar within media selector popup?');
@define('MEDIA_KEYWORDS', 'Media keywords');
@define('MEDIA_KEYWORDS_DESC', 'Enter a list of ";" separated words that you want to use as pre-defined keywords for media items.');
@define('MEDIA_EXIF', 'Import EXIF/JPEG image data');
@define('MEDIA_EXIF_DESC', 'If enabled, existing EXIF/JPEG metadata of images will be parsed and stored in the database for display in the media gallery.');
@define('MEDIA_PROP', 'Media properties');


@define('GO_ADD_PROPERTIES', 'Go & enter properties');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
@define('MEDIA_PROPERTY_COMMENT1', 'Short Comment');
@define('MEDIA_PROPERTY_COMMENT2', 'Long Comment');
@define('MEDIA_PROPERTY_TITLE', 'Title');
@define('MEDIA_PROP_DESC', 'Enter a list of ";" separated property fields you want to define for each media file');
@define('MEDIA_PROP_MULTIDESC', '(You can append ":MULTI" after any item to indicate that this item will contain long text instead of just some characters)');

@define('STYLE_OPTIONS_NONE', 'This theme/style has no specific options. To see how your template can specify options, read the Technical Documentation on www.s9y.org about "Configuration of Theme options".');
@define('STYLE_OPTIONS', 'Theme/Style options');

@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');

@define('SYNDICATION_RFC2616', 'Activate strict RFC2616 RSS-Feed compliance');
@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also violates RFC2616. So if you set this option to "TRUE" you will comply with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', 'Associated Date');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
@define('FILENAME_REASSIGNED', 'Automagically assigned new file name: %s');
@define('MEDIA_UPLOAD_SIZE', 'Max. file upload size');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Enter the maximum filesize for uploaded files in bytes. This setting can be overruled by server-side settings in PHP.ini: upload_max_filesize, post_max_size, max_input_time all take precedence over this option. An empty string means to only use the server-side limits.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Error: You cannot upload files larger than %s bytes!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. width of image files for upload');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Enter the maximum image width in pixels for uploaded images.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. height of image files for upload');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Enter the maximum image height in pixels for uploaded images.');
@define('MEDIA_UPLOAD_DIMERROR', 'Error: You cannot upload image files larger than %s x %s pixels!');

@define('MEDIA_TARGET', 'Target for this link');
@define('MEDIA_TARGET_JS', 'Popup window (via JavaScript, adaptive size)');
@define('MEDIA_ENTRY', 'Isolated Entry');
@define('MEDIA_TARGET_BLANK', 'Popup window (via target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Allow dynamic image resizing?');
@define('MEDIA_DYN_RESIZE_DESC', 'If enabled, the media selector can return images in any requested size via a GET variable. The results are cached, and thus can create a large filebase if you make intensive use of it.');

@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
@define('PLUGIN_ACTIVE', 'Active');
@define('PLUGIN_INACTIVE', 'Inactive');
@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');

@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
@define('SET_TO_MODERATED', 'Moderate');
@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
@define('CENTER', 'center');
